from setuptools import setup

setup(name='cqe-jdsu',
      version='0.2',
      description='package required for JDSU API',
      url='https://github.com/cafylib/cqe-jdsu',
      author='Deepesh Kaushal',
      author_email='kaushal_deepesh@yahoo.in',
      license='VIAVI',
      packages=['jdsu'],
      zip_safe=False)
